# Kanka for python

Hello there. This library/wrapper/whatever will help you a lot with dealing with kanka's API. For information about kanka, have a look at kanka.io.

For contacting me, join the kanka discord channel (https://discord.gg/rhsyZJ4) or PM me on Telegram (https://t.me/poolitzer).

Have a good day.


DISCLAIMER:

This is obviously a dev release. Don't use it until you know what you do.

Feel free to use it though, everything what currently can work will work and yeah. A documentation will be here once the kanka API has one and I know what should be here.